# DevTestLab

> see https://aka.ms/autorest

This is the AutoRest configuration file for DevTestLab.



---
## Getting Started
To build the SDK for DevTestLab, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the DevTestLab API.

``` yaml
openapi-type: arm
tag: package-2018-09
```


### Tag: package-2018-09

These settings apply only when `--tag=package-2018-09` is specified on the command line.

``` yaml $(tag) == 'package-2018-09'
input-file:
- Microsoft.DevTestLab/stable/2018-09-15/DTL.json
```

### Tag: package-2016-05

These settings apply only when `--tag=package-2016-05` is specified on the command line.

``` yaml $(tag) == 'package-2016-05'
input-file:
- Microsoft.DevTestLab/stable/2016-05-15/DTL.json
```

### Tag: package-2015-05-preview

These settings apply only when `--tag=package-2015-05-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-05-preview'
input-file:
- Microsoft.DevTestLab/preview/2015-05-21-preview/DTL.json
```


---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_devtestlabs']
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.DevTestLabs
  output-folder: $(csharp-sdks-folder)/DevTestLabs/Management.DevTestLabs/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.devtestlabs
  package-name: azure-mgmt-devtestlabs
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-devtestlabs/azure/mgmt/devtestlabs
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-devtestlabs
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.devtestlabs
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-devtestlabs
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2018-09
  - tag: package-2016-05
  - tag: package-2015-05-preview
```

### Tag: package-2018-09 and java

These settings apply only when `--tag=package-2018-09 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-09' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.devtestlab.v2018_09_15
  output-folder: $(azure-libraries-for-java-folder)/devtestlab/resource-manager/v2018_09_15
regenerate-manager: true
generate-interface: true
```

### Tag: package-2016-05 and java

These settings apply only when `--tag=package-2016-05 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2016-05' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.devtestlab.v2016_05_15
  output-folder: $(azure-libraries-for-java-folder)/devtestlab/resource-manager/v2016_05_15
regenerate-manager: true
generate-interface: true
```

### Tag: package-2015-05-preview and java

These settings apply only when `--tag=package-2015-05-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-05-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.devtestlab.v2015_05_21_preview
  output-folder: $(azure-libraries-for-java-folder)/devtestlab/resource-manager/v2015_05_21_preview
regenerate-manager: true
generate-interface: true
```


